# Changelog

All notable changes to `light-curve-dmdt` will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

### Changed

—

### Depreceted

—

### Removed

—

### Fixed

—

### Security

—

## [0.4.0]

### Changed

- `ndarray` is updated to 0.15.3, it is a breaking change


## [0.3.x]

—

## [0.2.x]

—

## [0.1.x]

—
